import requests
from bs4 import BeautifulSoup

from request import _get_response_content

class Monitor:
    def __init__(self) -> None:
        self.website = 'https://monitordolarvenezuela.com/'

    def _get_content(self, url: str):
        return _get_response_content(requests.get(url))
    
    def _get_results_price(self, soup: BeautifulSoup):
        return [str(x.find('p').text).split(' ')[-1].replace(',', '.') for x in soup.find_all('div', 'col-12 col-sm-4 col-md-2 col-lg-2')]
    
    def get_value_monitors(self, monitor_code: str = None, prettify: bool = False):
        page = self._get_content(self.website)
        soup = BeautifulSoup(page, features='html.parser')

        results = {
            'enparalelovzla': self._get_results_price(soup)[1],
            'monitordolarweb': self._get_results_price(soup)[3],
            'enparalelovzlavip': self._get_results_price(soup)[4],
            'binance': self._get_results_price(soup)[5]
        }

        if not monitor_code:
            return results
        if monitor_code not in results:
            raise KeyError("Does not match any of the properties that were provided in the dictionary. Most information: https://gothub.com/fcoagz/pydolarvenezuela")
        return results[monitor_code] if not prettify else f'Bs. {results[monitor_code]}'


import requests
from bs4 import BeautifulSoup

from request import _get_response_content

requests.packages.urllib3.disable_warnings()

class Bcv:
    def __init__(self) -> None:
        self.page_bcv = "https://www.bcv.org.ve/"
    
    def _get_content(self, web_site: str) -> bytes:
        return _get_response_content(requests.get(web_site))
    
    def _get_value_by_id(self, tag_id: str, soup: BeautifulSoup):
        return soup.find(id=tag_id).find("strong").text.strip().replace(',', '.')
    
    def get_rates(self, currency_code: str):
        content = self._get_content(self.page_bcv)
        soup = BeautifulSoup(content, "html.parser")
        section_tipo_de_cambio_oficial = soup.find("div", "view-tipo-de-cambio-oficial-del-bcv")

        rates = {
            "EUR": self._get_value_by_id("euro", section_tipo_de_cambio_oficial),
            "CNY": self._get_value_by_id("yuan", section_tipo_de_cambio_oficial),
            "TRY": self._get_value_by_id("lira", section_tipo_de_cambio_oficial),
            "RUB": self._get_value_by_id("rublo", section_tipo_de_cambio_oficial),
            "USD": self._get_value_by_id("dolar", section_tipo_de_cambio_oficial)
        }

        if not currency_code:
            return rates
        if currency_code not in rates:
            raise KeyError("Does not match any of the properties that were provided in the dictionary. Most information: https://gothub.com/fcoagz/pydolarvenezuela")
        return rates[currency_code]


import requests

def _get_response_content(response: requests.Response):
    if not response.status_code == requests.codes.ok:
        raise ValueError("Connection error on the page")
    return response.content